;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "jira" "20251011.1501"
  "Emacs Interface to Jira."
  '((emacs         "29.1")
    (request       "0.3.0")
    (tablist       "1.0")
    (transient     "0.8.3")
    (magit-section "4.2.0"))
  :url "https://github.com/unmonoqueteclea/jira.el"
  :commit "762c0e3bd9f46ef8f62b7954b66ef27772eb533d"
  :revdesc "762c0e3bd9f4"
  :authors '(("Pablo González Carrizo" . "unmonoqueteclea@gmail.com"))
  :maintainers '(("Pablo González Carrizo" . "unmonoqueteclea@gmail.com")))
